==> irssi_0.7.21.orig.tar.gz: irssi-0.7.21/src/ui-common/txt.h <==
#ifndef __TXT_H
#define __TXT_H

enum
{
    IRCTXT_FILL_1,

    IRCTXT_LINE_START,
    IRCTXT_LINE_START_IRSSI,
    IRCTXT_TIMESTAMP,
    IRCTXT_DAYCHANGE,

    IRCTXT_FILL_2,

    IRCTXT_LOOKING_UP,
    IRCTXT_CONNECTING,
    IRCTXT_CONNECTION_ESTABLISHED,
    IRCTXT_CANT_CONNECT,
    IRCTXT_CONNECTION_LOST,
    IRCTXT_LAG_DISCONNECTED,
    IRCTXT_DISCONNECTED,
    IRCTXT_SERVER_CHANGED,
    IRCTXT_UNKNOWN_SERVER_TAG,

    IRCTXT_FILL_3,

    IRCTXT_JOIN,
    IRCTXT_PART,
    IRCTXT_TALKING_IN,
    IRCTXT_JOINERROR_TOOMANY,
    IRCTXT_JOINERROR_FULL,
    IRCTXT_JOINERROR_INVITE,
    IRCTXT_JOINERROR_BANNED,
    IRCTXT_JOINERROR_BAD_KEY,
    IRCTXT_JOINERROR_BAD_MASK,
    IRCTXT_JOINERROR_UNAVAIL,
    IRCTXT_KICK,
    IRCTXT_QUIT,
    IRCTXT_INVITE,
    IRCTXT_NAMES,
    IRCTXT_ENDOFNAMES,
    IRCTXT_CHANNEL_CREATED,
    IRCTXT_TOPIC,
    IRCTXT_NO_TOPIC,
    IRCTXT_NEW_TOPIC,
    IRCTXT_TOPIC_UNSET,
    IRCTXT_TOPIC_INFO,
    IRCTXT_CHANMODE_CHANGE,
    IRCTXT_SERVER_CHANMODE_CHANGE,
    IRCTXT_CHANNEL_MODE,
    IRCTXT_BANTYPE,
    IRCTXT_BANLIST,
    IRCTXT_BANLIST_LONG,
    IRCTXT_EBANLIST,
    IRCTXT_EBANLIST_LONG,
    IRCTXT_INVITELIST,
    IRCTXT_NO_SUCH_CHANNEL,
    IRCTXT_CHANNEL_SYNCED,

    IRCTXT_FILL_4,

    IRCTXT_USERMODE_CHANGE,
    IRCTXT_USER_MODE,
    IRCTXT_AWAY,
    IRCTXT_UNAWAY,
    IRCTXT_NICK_AWAY,
    IRCTXT_NO_SUCH_NICK,
    IRCTXT_YOUR_NICK_CHANGED,
    IRCTXT_NICK_CHANGED,
    IRCTXT_NICK_IN_USE,
    IRCTXT_NICK_UNAVAILABLE,
    IRCTXT_YOUR_NICK_OWNED,

    IRCTXT_FILL_5,

    IRCTXT_WHOIS,
    IRCTXT_WHOIS_IDLE,
    IRCTXT_WHOIS_IDLE_SIGNON,
    IRCTXT_WHOIS_SERVER,
    IRCTXT_WHOIS_OPER,
    IRCTXT_WHOIS_CHANNELS,
    IRCTXT_WHOIS_AWAY,
    IRCTXT_END_OF_WHOIS,
    IRCTXT_WHO,
    IRCTXT_END_OF_WHO,

    IRCTXT_FILL_6,

    IRCTXT_OWN_MSG,
    IRCTXT_OWN_MSG_CHANNEL,
    IRCTXT_OWN_MSG_PRIVATE,
    IRCTXT_OWN_MSG_PRIVATE_QUERY,
    IRCTXT_OWN_NOTICE,
    IRCTXT_OWN_ME,
    IRCTXT_OWN_CTCP,
    IRCTXT_OWN_DCC,

    IRCTXT_FILL_7,

    IRCTXT_PUBMSG_ME,
    IRCTXT_PUBMSG_ME_CHANNEL,
    IRCTXT_PUBMSG,
    IRCTXT_PUBMSG_CHANNEL,
    IRCTXT_MSG_PRIVATE,
    IRCTXT_MSG_PRIVATE_QUERY,
    IRCTXT_DCC_MSG,
    IRCTXT_NOTICE_SERVER,
    IRCTXT_NOTICE_PUBLIC,
    IRCTXT_NOTICE_PRIVATE,
    IRCTXT_ACTION_DCC,
    IRCTXT_ACTION_PRIVATE,
    IRCTXT_ACTION_PRIVATE_QUERY,
    IRCTXT_ACTION_PUBLIC,
    IRCTXT_ACTION_PUBLIC_CHANNEL,

    IRCTXT_FILL_8,

    IRCTXT_CTCP_REPLY,
    IRCTXT_CTCP_PING_REPLY,
    IRCTXT_CTCP_REQUESTED,
    IRCTXT_DCC_CTCP,

    IRCTXT_FILL_9,

    IRCTXT_DCC_CHAT,
    IRCTXT_DCC_CHAT_NOT_FOUND,
    IRCTXT_DCC_CHAT_CONNECTED,
    IRCTXT_DCC_CHAT_DISCONNECTED,
    IRCTXT_DCC_SEND,
    IRCTXT_DCC_SEND_EXISTS,
    IRCTXT_DCC_SEND_NOT_FOUND,
    IRCTXT_DCC_SEND_FILE_NOT_FOUND,
    IRCTXT_DCC_SEND_CONNECTED,
    IRCTXT_DCC_SEND_COMPLETE,
    IRCTXT_DCC_SEND_ABORTED,
    IRCTXT_DCC_GET_NOT_FOUND,
    IRCTXT_DCC_GET_CONNECTED,
    IRCTXT_DCC_GET_COMPLETE,
    IRCTXT_DCC_GET_ABORTED,
    IRCTXT_DCC_UNKNOWN_CTCP,
    IRCTXT_DCC_UNKNOWN_REPLY,
    IRCTXT_DCC_UNKNOWN_COMMAND,
    IRCTXT_DCC_UNKNOWN_TYPE,
    IRCTXT_DCC_CONNECT_ERROR,
    IRCTXT_DCC_CANT_CREATE,
    IRCTXT_DCC_REJECTED,
    IRCTXT_DCC_CLOSE,

    IRCTXT_FILL_10,

    IRCTXT_ONLINE,
    IRCTXT_PONG,
    IRCTXT_WALLOPS,
    IRCTXT_ACTION_WALLOPS,
    IRCTXT_ERROR,
    IRCTXT_UNKNOWN_MODE,
    IRCTXT_NOT_CHANOP,

    IRCTXT_FILL_11,

    IRCTXT_LOG_OPENED,
    IRCTXT_LOG_OPEN_FAILED,
    IRCTXT_LOG_NOT_OPEN,
    IRCTXT_LOG_CLOSED,
    IRCTXT_LOG_LISTENTRY,
    IRCTXT_LOG_SUBLISTENTRY,

    IRCTXT_FILL_12,

    IRCTXT_LEVELS_ERROR,
    IRCTXT_IGNORED,
    IRCTXT_UNIGNORED,
    IRCTXT_IGNORE_NOT_FOUND,
    IRCTXT_AUTOIGNORE,
    IRCTXT_AUTOUNIGNORE,
    IRCTXT_LASTLOG_START,
    IRCTXT_LASTLOG_END,
    IRCTXT_IRCJOIN,
    IRCTXT_IRCPART,
    IRCTXT_NOTIFY_ONLINE,
    IRCTXT_NOTIFY_OFFLINE,
    IRCTXT_NO_QUERY,
    IRCTXT_PLUGIN_LOAD_ERROR,
    IRCTXT_PLUGIN_INVALID,
    IRCTXT_PLUGIN_INVALID_VERSION,
    IRCTXT_PLUGIN_ALREADY_LOADED,
    IRCTXT_PLUGIN_NOT_LOADED,

    TEXTS
};

#endif

==> irssi_0.7.28.orig.tar.gz: irssi-0.7.28/src/ui-common/txt.h <==
#ifndef __TXT_H
#define __TXT_H

enum
{
    IRCTXT_FILL_1,

    IRCTXT_LINE_START,
    IRCTXT_LINE_START_IRSSI,
    IRCTXT_TIMESTAMP,
    IRCTXT_DAYCHANGE,

    IRCTXT_FILL_2,

    IRCTXT_LOOKING_UP,
    IRCTXT_CONNECTING,
    IRCTXT_CONNECTION_ESTABLISHED,
    IRCTXT_CANT_CONNECT,
    IRCTXT_CONNECTION_LOST,
    IRCTXT_LAG_DISCONNECTED,
    IRCTXT_DISCONNECTED,
    IRCTXT_SERVER_CHANGED,
    IRCTXT_UNKNOWN_SERVER_TAG,
    IRCTXT_SERVER_LIST,
    IRCTXT_SERVER_LOOKUP_LIST,
    IRCTXT_SERVER_RECONNECT_LIST,
    IRCTXT_RECONNECT_REMOVED,
    IRCTXT_RECONNECT_NOT_FOUND,
    IRCTXT_FILL_3,

    IRCTXT_JOIN,
    IRCTXT_PART,
    IRCTXT_TALKING_IN,
    IRCTXT_JOINERROR_TOOMANY,
    IRCTXT_JOINERROR_FULL,
    IRCTXT_JOINERROR_INVITE,
    IRCTXT_JOINERROR_BANNED,
    IRCTXT_JOINERROR_BAD_KEY,
    IRCTXT_JOINERROR_BAD_MASK,
    IRCTXT_JOINERROR_UNAVAIL,
    IRCTXT_KICK,
    IRCTXT_QUIT,
    IRCTXT_INVITE,
    IRCTXT_NAMES,
    IRCTXT_ENDOFNAMES,
    IRCTXT_CHANNEL_CREATED,
    IRCTXT_TOPIC,
    IRCTXT_NO_TOPIC,
    IRCTXT_NEW_TOPIC,
    IRCTXT_TOPIC_UNSET,
    IRCTXT_TOPIC_INFO,
    IRCTXT_CHANMODE_CHANGE,
    IRCTXT_SERVER_CHANMODE_CHANGE,
    IRCTXT_CHANNEL_MODE,
    IRCTXT_BANTYPE,
    IRCTXT_BANLIST,
    IRCTXT_BANLIST_LONG,
    IRCTXT_EBANLIST,
    IRCTXT_EBANLIST_LONG,
    IRCTXT_INVITELIST,
    IRCTXT_NO_SUCH_CHANNEL,
    IRCTXT_CHANNEL_SYNCED,

    IRCTXT_FILL_4,

    IRCTXT_USERMODE_CHANGE,
    IRCTXT_USER_MODE,
    IRCTXT_AWAY,
    IRCTXT_UNAWAY,
    IRCTXT_NICK_AWAY,
    IRCTXT_NO_SUCH_NICK,
    IRCTXT_YOUR_NICK_CHANGED,
    IRCTXT_NICK_CHANGED,
    IRCTXT_NICK_IN_USE,
    IRCTXT_NICK_UNAVAILABLE,
    IRCTXT_YOUR_NICK_OWNED,

    IRCTXT_FILL_5,

    IRCTXT_WHOIS,
    IRCTXT_WHOIS_IDLE,
    IRCTXT_WHOIS_IDLE_SIGNON,
    IRCTXT_WHOIS_SERVER,
    IRCTXT_WHOIS_OPER,
    IRCTXT_WHOIS_CHANNELS,
    IRCTXT_WHOIS_AWAY,
    IRCTXT_END_OF_WHOIS,
    IRCTXT_WHO,
    IRCTXT_END_OF_WHO,

    IRCTXT_FILL_6,

    IRCTXT_OWN_MSG,
    IRCTXT_OWN_MSG_CHANNEL,
    IRCTXT_OWN_MSG_PRIVATE,
    IRCTXT_OWN_MSG_PRIVATE_QUERY,
    IRCTXT_OWN_NOTICE,
    IRCTXT_OWN_ME,
    IRCTXT_OWN_CTCP,
    IRCTXT_OWN_DCC,

    IRCTXT_FILL_7,

    IRCTXT_PUBMSG_ME,
    IRCTXT_PUBMSG_ME_CHANNEL,
    IRCTXT_PUBMSG_HILIGHT,
    IRCTXT_PUBMSG_HILIGHT_CHANNEL,
    IRCTXT_PUBMSG,
    IRCTXT_PUBMSG_CHANNEL,
    IRCTXT_MSG_PRIVATE,
    IRCTXT_MSG_PRIVATE_QUERY,
    IRCTXT_DCC_MSG,
    IRCTXT_NOTICE_SERVER,
    IRCTXT_NOTICE_PUBLIC,
    IRCTXT_NOTICE_PUBLIC_OPS,
    IRCTXT_NOTICE_PRIVATE,
    IRCTXT_ACTION_DCC,
    IRCTXT_ACTION_PRIVATE,
    IRCTXT_ACTION_PRIVATE_QUERY,
    IRCTXT_ACTION_PUBLIC,
    IRCTXT_ACTION_PUBLIC_CHANNEL,

    IRCTXT_FILL_8,

    IRCTXT_CTCP_REPLY,
    IRCTXT_CTCP_PING_REPLY,
    IRCTXT_CTCP_REQUESTED,
    IRCTXT_DCC_CTCP,

    IRCTXT_FILL_9,

    IRCTXT_DCC_CHAT,
    IRCTXT_DCC_CHAT_NOT_FOUND,
    IRCTXT_DCC_CHAT_CONNECTED,
    IRCTXT_DCC_CHAT_DISCONNECTED,
    IRCTXT_DCC_SEND,
    IRCTXT_DCC_SEND_EXISTS,
    IRCTXT_DCC_SEND_NOT_FOUND,
    IRCTXT_DCC_SEND_FILE_NOT_FOUND,
    IRCTXT_DCC_SEND_CONNECTED,
    IRCTXT_DCC_SEND_COMPLETE,
    IRCTXT_DCC_SEND_ABORTED,
    IRCTXT_DCC_GET_NOT_FOUND,
    IRCTXT_DCC_GET_CONNECTED,
    IRCTXT_DCC_GET_COMPLETE,
    IRCTXT_DCC_GET_ABORTED,
    IRCTXT_DCC_UNKNOWN_CTCP,
    IRCTXT_DCC_UNKNOWN_REPLY,
    IRCTXT_DCC_UNKNOWN_TYPE,
    IRCTXT_DCC_CONNECT_ERROR,
    IRCTXT_DCC_CANT_CREATE,
    IRCTXT_DCC_REJECTED,
    IRCTXT_DCC_CLOSE,

    IRCTXT_FILL_10,

    IRCTXT_ONLINE,
    IRCTXT_PONG,
    IRCTXT_WALLOPS,
    IRCTXT_ACTION_WALLOPS,
    IRCTXT_ERROR,
    IRCTXT_UNKNOWN_MODE,
    IRCTXT_NOT_CHANOP,

    IRCTXT_FILL_11,

    IRCTXT_LOG_OPENED,
    IRCTXT_LOG_OPEN_FAILED,
    IRCTXT_LOG_NOT_OPEN,
    IRCTXT_LOG_CLOSED,
    IRCTXT_LOG_LISTENTRY,
    IRCTXT_LOG_SUBLISTENTRY,

    IRCTXT_FILL_12,

    IRCTXT_LEVELS_ERROR,
    IRCTXT_IGNORED,
    IRCTXT_UNIGNORED,
    IRCTXT_IGNORE_NOT_FOUND,
    IRCTXT_AUTOIGNORE,
    IRCTXT_AUTOUNIGNORE,
    IRCTXT_LASTLOG_START,
    IRCTXT_LASTLOG_END,
    IRCTXT_IRCJOIN,
    IRCTXT_IRCPART,
    IRCTXT_NOTIFY_ONLINE,
    IRCTXT_NOTIFY_OFFLINE,
    IRCTXT_NO_QUERY,
    IRCTXT_PLUGIN_LOAD_ERROR,
    IRCTXT_PLUGIN_INVALID,
    IRCTXT_PLUGIN_INVALID_VERSION,
    IRCTXT_PLUGIN_ALREADY_LOADED,
    IRCTXT_PLUGIN_NOT_LOADED,
    IRCTXT_PERL_ERROR,

    TEXTS
};

#endif
